@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("3.4.") or
-    raise "ruby lib version (3.4.1) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (3.4.5) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.4.0/aarch64-mingw-ucrt")
@@ -21,8 +21,8 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
   CONFIG["MINOR"] = "4"
-  CONFIG["TEENY"] = "1"
-  CONFIG["PATCHLEVEL"] = "0"
+  CONFIG["TEENY"] = "5"
+  CONFIG["PATCHLEVEL"] = "51"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ".exe"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/clangarm64")
@@ -45,7 +45,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/clangarm64' '--build=aarch64-w64-mingw32' '--disable-install-doc' '--with-setjmp-type=setjmp' 'build_alias=aarch64-w64-mingw32' 'CC=clang' 'CXX=clang++' 'CFLAGS=-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -Wno-dll-attribute-on-redeclaration' 'LDFLAGS=' 'CPPFLAGS=' 'CXXFLAGS=-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1'"
+  CONFIG["configure_args"] = " '--prefix=/clangarm64' '--build=aarch64-w64-mingw32' '--disable-install-doc' '--with-setjmp-type=setjmp' 'build_alias=aarch64-w64-mingw32' 'CC=clang' 'CXX=clang++' 'CFLAGS=-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -Wno-dll-attribute-on-redeclaration' 'LDFLAGS= -pthread' 'CPPFLAGS= -pthread' 'CXXFLAGS=-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -141,7 +141,7 @@ module RbConfig
   CONFIG["CCDLFLAGS"] = ""
   CONFIG["STATIC"] = ""
   CONFIG["ARCH_FLAG"] = ""
-  CONFIG["DLDFLAGS"] = " -Wl,--enable-auto-image-base,--enable-auto-import"
+  CONFIG["DLDFLAGS"] = " -pthread -Wl,--enable-auto-image-base,--enable-auto-import"
   CONFIG["ALLOCA"] = ""
   CONFIG["EGREP"] = "/usr/bin/grep -E"
   CONFIG["GREP"] = "/usr/bin/grep"
@@ -171,7 +171,7 @@ module RbConfig
   CONFIG["WINDRES"] = "windres"
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "clang version 19.1.6\nTarget: aarch64-w64-windows-gnu\nThread model: posix\nInstalledDir: C:/msys64/clangarm64/bin"
+  CONFIG["CC_VERSION_MESSAGE"] = "clang version 20.1.8\nTarget: aarch64-w64-windows-gnu\nThread model: posix\nInstalledDir: C:/M/msys64/clangarm64/bin"
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
@@ -182,8 +182,8 @@ module RbConfig
   CONFIG["CPP"] = "$(CC) -E"
   CONFIG["CXXFLAGS"] = "-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -fdeclspec"
   CONFIG["OBJEXT"] = "o"
-  CONFIG["CPPFLAGS"] = "-D_WIN32_WINNT=0x0600 -D__MINGW_USE_VC2005_COMPAT $(DEFS) $(cppflags)"
-  CONFIG["LDFLAGS"] = "-L. -fstack-protector-strong"
+  CONFIG["CPPFLAGS"] = " -pthread -D_WIN32_WINNT=0x0600 -D__MINGW_USE_VC2005_COMPAT $(DEFS) $(cppflags)"
+  CONFIG["LDFLAGS"] = "-L.  -pthread -fstack-protector-strong"
   CONFIG["CFLAGS"] = "-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -Wno-dll-attribute-on-redeclaration $(cflags)"
   CONFIG["STRIP"] = "llvm-strip -S -x"
   CONFIG["RANLIB"] = "llvm-ranlib"
